/**<pre>
 * Title: GPS Simulator
 * Copyright: Copyright (c) 2002
 * Company:   University of Oregon Computer Science Dept.
 *
 * @author Jason Prideaux
 * @version 1.0
 * </pre>
 */

package util;

/* ====================================================================== */
/** This class represents a gps position location, a gps position contains
 *  the latitude, longitude, heading, and other information.
 *
 */
public class Position{

	/** Latitude. */
  	private double lat;

	/** Longitude. */
  	private double lng;

	/** Tracking used in real gps, needed to determine heading. */
  	private double track;

	/** The current movement speed determined by tracking and time. */
  	private double speed;

	/** The current world time for this timezone. */
  	private long time;

	/** The compass heading. */
  	private double heading;




    /* ===================================================================== */
    /** This constructor instantiates the GPS Position object with default
     *  values for the gps coordinate position.  All variables are set as the
     *  system gets them.
     *
     */
	public Position(){

  		lat = 0;
  		lng = 0;
  		track = 0;
  		speed = 0;
  		time = 0;
  		heading = 180;

	} //Constructor



    /* ===================================================================== */
    /** This method returns the time.
     *
     *  @return  long   The time in millisecons currently.
     *
     */
	public long getTime(){

		return time;

	} //method: getTime



    /* ===================================================================== */
    /** This method sets the time.
     *
     *  @param  time   The time.
     *
     */
	public void setTime(long time){

		this.time = time;

	} //method: setTime



    /* ===================================================================== */
    /** This method returns the heading.
     *
     *  @return  double   The heading as a double.
     *
     */
	public double getHeading(){

		return heading;

	} //method: getHeading



    /* ===================================================================== */
    /** This method sets the heading.
     *
     *  @param  h   The heading.
     *
     */
	public void setHeading(double h){

		this.heading = h;

	} //method: setHeading




    /* ===================================================================== */
    /** This method returns the latitude.
     *
     *  @return  double   The latitude.
     *
     */
  	public double getLatitude(){

		String latitude = "";

		latitude += (int)lat/60;

		if( lat%60 < 10 )
			latitude += "0"+lat%60;
		else
			latitude += lat%60;

		return Double.parseDouble(latitude);

	} //method: getLatitude



    /* ===================================================================== */
    /** This method sets the latitude.
     *
     *  @param  l   The latitude.
     *
     */
	public void setLatitude(double l){

		lat = l;

	} //method: setLatitude





    /* ===================================================================== */
    /** This method returns the longitude.
     *
     *  @return  double   The longitude.
     *
     */
  	public double getLongitude(){

		String longitude = "-";

		longitude += (int)lng/60;

		if( lng%60 < 10 )
			longitude += "0"+lng%60;
		else
			longitude += lng%60;

		return Double.parseDouble(longitude);

	} //method: getLongitude




    /* ===================================================================== */
    /** This method sets the longitude.
     *
     *  @param  l   The longitude.
     *
     */
	public void setLongitude(double l){

		lng = l;


	} //method: setLongitude





    /* ===================================================================== */
    /** This method returns a String of the GPS Position in a NMEA format.
     *
     *  @return  String   The nmea String for this Position object.
     *
     */
  	public String toString(){

    	return(ChartWord.timeString(time)+" "+
     	ReferencePoint.toStringLatLng(lat,'N','S')+" "+
     	ReferencePoint.toStringLatLng(lng,'E','W')+" "+
     	track+" "+speed);

  	} //method: toString


} //class: Position

